/**
 * Implements a dice object (a die)
 */

import java.util.Random;

public class Dice
{
    private int rollCount;
    private int sides;
    private Random rand;

    /**
     * Constructs a standard 6-sided die
     */
    public Dice()
    {
	this(6);
    }

    /**
     * Constructs an n-sided die
     * @param n - the number of sides on the die
     */
    public Dice(int n)
    {
	rand = new Random();
	rollCount = 0;
	sides = n;
    }

    /**
     * Rolls a die - generates a random number in 1 .. numSides
     * @return the face value of the die
     */
    public int roll()
    {
	rollCount++;
	return rand.nextInt(sides) + 1;
    }

    /**
     * Returns the number of sides of the die
     * @return the number of sides
     */
    public int numSides()
    {
	return sides;
    }

    /**
     * Returns the number of times the die has been rolled
     * @return the number of rolls
     */
    public int numRolls()
    {
	return rollCount;
    }

    /**
     * Returns a string representing this die
     * @return the string representation
     */
    public String toString()
    {
	return "This die has " + sides + " sides and has been rolled " + rollCount + "times.";
    }
}
